;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xea436aee5b5118bbddf4e83a6abec59f . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xa2c2c164e86f7fc3d56ad9e1830d1c53 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x1f0a40a331a1127ec2c144805945a99a . "./code.cg2js/cg-toolbar.fasl")
(#xffdc0563e57a63d7aa00963c8ba96e84 . "./code.cg2js/cg-chart-or-plot.fasl")
(#xd9b7d68692be4e8c80c00341eae8b542 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xb7040f783a0e6224f062dbccae3d7417 . "./code.cg2js/cg-class-grid.fasl")
(#x23e351c905e3a915149c76136427c41b . "./code.cg2js/cg-tray.fasl")
(#x9549047a1be026f9ecbcad63a1dbf76d . "./code.cg2js/cg-gesture-emulation.fasl")
(#x9bbc422eb3a2c50975fb9fc5edbb1b68 . "./code.cg2js/cg-class-support.fasl")
(#x9e95ed3cecc44bebfe7917c9e176a86c . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x5bb8f9efad8fe5fd3177442a0994547c . "./code.cg2js/cg-dropping-outline.fasl")
(#x1d183d96247c59ac43bb84c1f79694fa . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x0d42e2f6ef61f4c45be9b9c428e4dd85 . "./code.cg2js/cg-choice-list.fasl")
(#x4534cf0d022e1e8fc91ac0b019ccf8ff . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xa400e1855fda64881ed84983f959c509 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x8d124578b6aff4f3196a262c22905117 . "./code.cg2js/cg-timer.fasl")
(#xd1682a7ac4bab632c4aed2d5bf5254c4 . "./code.cg2js/cg-directory-dialog.fasl")
(#x9556b02797e0b1bd6845e6a855788339 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xcf482b8056d29e0b0be9d9d7de4a6efa . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x634a56a82c817ba403b9c7dbf065d555 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x7eb4a4a172020f91889ed794f993d28d . "./code.cg2js/cg-html-widget.fasl")
(#x80c90ef0b90cfe98c2630046d1f394f1 . "./code.cg2js/cg-selected-object.fasl")
(#x65bbeae632db1366ffd462545cbb8df7 . "./code.cg2js/cg-lamp.fasl")
(#x31cbd11f9dbff7b062b697298e21d03b . "./code.cg2js/cg-scroll-bar.fasl")
(#x4f55640dcb97dfdeb4786a648b6eb71d . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xe30ffc4b1e91c14baa593414c3a00072 . "./code.cg2js/cg-message-dialog.fasl")
(#x2cfc2ad3bff983515d97d7ee8bbc47cd . "./code.cg2js/cg-dde-utils.fasl")
(#x8bef8e44a4ef0ee0e33105fe15feca5a . "./code.cg2js/cg-group-box.fasl")
(#xc137f50788cff038ab34c4648bc4c1c7 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x4f52c3d773a3c5cab5ba3a33db23ca26 . "./code.cg2js/cg-split-bar.fasl")
(#xf3e7afe8b849c368a79b80656e4643ab . "./code.cg2js/cg-radio-button.fasl")
(#x809da2739947f775e3869b94d76f369b . "./code.cg2js/cg-base.fasl")
(#x826c530a735526bb1071a41bdc738efd . "./code.cg2js/cg-paren-matching.fasl")
(#x47ca5457308fd04840b39199091e533c . "./code.cg2js/cg-graphics-context.fasl")
(#x24c3f1c8394698d5614bb17b57c90d73 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xd1c3e94212fa6d4365458715656bcdf9 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x433d68013bba7a81e3af7d5c2f5e4208 . "./code.cg2js/cg-plot-widget.fasl")
(#x107ee70a4525b48a47bc97efd350d2a9 . "./code.cg2js/cg-dev.fasl")
(#x3bce5079b7260ea60c90ec13fa884e26 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x0261cf3c8ec4137796c6a404da017cf7 . "./code.cg2js/cg-tab-control.fasl")
(#xacf1b7a67eea0189998df85de4c67069 . "./code.cg2js/cg-fill-texture.fasl")
(#x4d65e60df6e7e34f547c47b7da5616ea . "./code.cg2js/cg-menu-tooltip.fasl")
(#x0c3fbdcaa3f0fbe326c96dcba8f580ed . "./code.cg2js/cg-trackbar.fasl")
(#x86bd5c8ec99e7dccbe80cb98527d9b40 . "./code.cg2js/cg-nodes.fasl")
(#xf549161fa5556fc2fd99b2e37339ddf3 . "./code.cg2js/cg-common-control.fasl")
(#x6f33b4c35adc4006af7c1f7ab239c9a7 . "./code.cg2js/cg-list-view.fasl")
(#x47bcd3ad425d3afeae7307c0effcd5b5 . "./code.cg2js/cg-rich-edit.fasl")
(#xe590a03db200d33b4c680c5680fe68fb . "./code.cg2js/cg-project-window.fasl")
(#xa51b51998d62db2b5dff30c874d9b4a7 . "./code.cg2js/cg-item-list.fasl")
(#x432b22e5eeba33a52a6bbb1418b0cae9 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x3bb82235d39e2db71f79b4828799be08 . "./code.cg2js/cg-get-position.fasl")
(#xf279f03ccae903b3e04373a1122acecb . "./code.cg2js/cg-bitmap-pane.fasl")
(#x7868678057880b0eb62c5f43c14feac1 . "./code.cg2js/cg-drawable.fasl")
(#x51ee7b1b2e9108b683d7b41f0a7f441b . "./code.cg2js/cg-lettered-menu.fasl")
(#x80b0e4cb90c098d2e7842de8ab7accdb . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x7dba837c79e554a78e84c9e9b1e78b57 . "./code.cg2js/cg-html-dialog.fasl")
(#x4345a243cfffcb85c06d8662abb8f9f9 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x13561639ba0044377d1ff1a5d4ca21a5 . "./code.cg2js/cg-utility-dialog.fasl")
(#x495671a7a32764bddb411578b77b89d7 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x1a219b57d76936922e42fc68ef73f855 . "./code.cg2js/cg-property.fasl")
(#x657e8bf66b6c9bcfca032c8cb94d3095 . "./code.cg2js/cg-menu.fasl")
(#x2628e3eeb2d9ad56f5692e9a92ecd89c . "./code.cg2js/cg-clipboard.fasl")
(#xbd007cf648331d8b0d6c90fbf79b3e53 . "./code.cg2js/cg-toggling-widget.fasl")
(#x9b649fe6b1d64099b28f9457579d4dd3 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x02089ff1ca5db12c2a857116a7768c33 . "./code.cg2js/cg-template-string.fasl")
(#x12e78a41a5febd20c515b32d7885fb50 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x6c80181ff531ba57741ebab271cc514b . "./code.cg2js/cg-os-window.fasl")
(#x646558ab529ba551727f0d4a12015950 . "./code.cg2js/cg-grid-widget.fasl")
(#xc9a1fea916274142173b1f9e532624a0 . "./code.cg2js/cg-picture-widget.fasl")
(#x765ed0692f7f77f76f97e0758df749b5 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x334a7321cf247ce548d187fde4787b58 . "./code.cg2js/cg-static-text.fasl")
(#x2a875026b16a10b1c01fcdd3806efe4f . "./code.cg2js/cg-clipboard-stack.fasl")
(#x0c486bde893b68ba18ca387c579fb234 . "./code.cg2js/cg-text-widget.fasl")
(#x02050a66fc68f01eb53187f75157f52e . "./code.cg2js/cg-calendar.fasl")
(#xaac188803af61e0967dcf16bf478a20a . "./code.cg2js/cg-check-box.fasl")
(#x7929a63d84ccf2b4296e65d82545a390 . "./code.cg2js/cg-acache.fasl")
(#x4399beaea4d2f40f3f91afe5c7102960 . "./code.cg2js/cg-wrap-string.fasl")
(#x36431a3057b5209f186e96434929c85e . "./code.cg2js/cg-bitmap-stream.fasl")
(#xab537cfeda513e81de078496871ccdee . "./code.cg2js/cg-font-dialog.fasl")
(#x93454d6a360165d45ec2efabde96e513 . "./code.cg2js/cg-outline.fasl")
(#xb24018d2f71aba8c5401ef5c9d394220 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x4c99019c41a04d7cf2e46eee05d909e1 . "./code.cg2js/cg-status-bar.fasl")
(#x2e0a03c08b900e4ba313dd3d886e46cd . "./code.cg2js/cg-multi-picture-button.fasl")
(#xdd08dcefa58fc455f378fff8672ffb01 . "./code.cg2js/cg-hotspot.fasl")
(#x3114973b339595b0bcc2d5c18e70a9c9 . "./code.cg2js/cg-scaling-stream.fasl")
(#xf80b2afc5d881fb058843d8c963ffcca . "./code.cg2js/cg-icon-pixmap.fasl")
(#x07a696a02c8abbe9cbcd9481c18dd2aa . "./code.cg2js/cg-file-dialog.fasl")
(#xf96a5e40d401b04f8bb2ea86346a1a63 . "./code.cg2js/cg-color-dialog.fasl")
(#xe3aa511e86b8791bf0c11a541bb6eb78 . "./code.cg2js/cg-get-pixmap.fasl")
(#x8fc54691c0872513b5ad4003db72916e . "./code.cg2js/cg-object-editor.fasl")
(#x08b700c711da8cc5ae74d7063f6ba1ee . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xb50616d22b5bc9db0e90914a867db476 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xc47f09ef245930fae6b471a981fd4a29 . "./code.cg2js/cg-pixmap.fasl")
(#xe2800a08814f54605cffd8d90e313c74 . "./code.cg2js/cg-intersect.fasl")
(#x18ed5718dc5865f7f11e8d553df37d47 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x961eb96fa3131d9453ad3058c3f5d613 . "./code.cg2js/cg-icon.fasl")
(#x0a01e46c424c41fd6557a887cc3e0c8e . "./code.cg2js/cg-yes-no-string.fasl")
(#x625eac11bd2afbd422eb4aaf1d240d37 . "./code.cg2js/cg-text-or-combo.fasl")
(#x8b94a4e15e8fc8905075e4b296e81921 . "./code.cg2js/cg.fasl")
(#x902cea6d6b0724db2b35cdc03af9a4e6 . "./code.cg2js/cg-dialog-item.fasl")
(#x9e5e5c3b197c0770847efd0be68166c4 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xe3ce8f7f4351b6d9eb02be23172e451d . "./code.cg2js/cg-caret.fasl")
(#xccd17ba11b87f4827a28242d93668a63 . "./code.cg2js/cg-editable-text.fasl")
(#xe8a235a7e1ff1930674be6fa28cae950 . "./code.cg2js/cg-choose-printer.fasl")
(#xdac40cc3a14362e0955b4569684f0ceb . "./code.cg2js/cg-yes-no-list.fasl")
(#x2c7505659f14e726c909d18253ee0553 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xbdb33709892e1896292c61d34029ea18 . "./code.cg2js/cg-tooltip.fasl")
(#xb268077afa676644f0ab5ef9209d97a2 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xddc3bcb44660fd2d8fa34faf6118d5c0 . "./code.cg2js/cg-combo-box.fasl")
(#x8ba98ba3cbb27c6120d41aed4857ab70 . "./code.cg2js/cg-curve.fasl")
(#xf74db9e4dca99ba227610b8bcaef930e . "./code.cg2js/cg-web-browser.fasl")
(#xf5e0a9c02949d31f9b291f13ab3dd20f . "./code.cg2js/cg-printing.fasl")
(#x5e20642407cadb873fabf7d2aea5560d . "./code.cg2js/cg-lisp-widget.fasl")
(#xbe3c4bc85ae3656b534f9c34606e0d32 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x7d4f384624e9a306a8cda86201907d4a . "./code.cg2js/cg-palette.fasl")
(#x9934f13123b083571304548a4d95802e . "./code.cg2js/cg-os-widget.fasl")
(#x85713ebd6228a505bb08712f3092170b . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x47f4b43bbb2914e54b6ccc005a99482e . "./code.cg2js/cg-pixmap-printing.fasl")
(#x0fd51064af694f77c5262f4a6e3b8182 . "./code.cg2js/cg-button.fasl")
(#xf803b39deecc8255972c88c5c43c5ddd . "./code.cg2js/cg-edit-in-place.fasl")
(#x867f9b2f9293a8c019f527a315d89ab8 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x23573ce2caa55de82ef8f7dc119eb001 . "./code.cg2js/cg-comtab.fasl")
(#xc01b7d4f0b8ecf75091bb77ad9560c82 . "./code.cg2js/cg-string-dialog.fasl")
(#xa46ff2f48a1811ec9b070ac9ca416e3e . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x474c56885e51e1a1047d1314f56075c4 . "./code.cg2js/cg-up-down-control.fasl")
(#x903d08bb2ab1e1efd3fe5d1b7137956d . "./code.cg2js/cg-layout.fasl")
(#xf6cfa7eacf78fd90a3396def70a8ce26 . "./code.cg2js/cg-chart-widget.fasl")
(#x58c1edb2e0b062f196bdbefca2538147 . "./code.cg2js/cg-lisp-text.fasl")
(#x522be9f7dbddedbc82e13b32812a1e81 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x35ce8298daa40dcbb6d722e8766c62fa . "./code.cg2js/cg-progress-indicator.fasl")
(#xc785c4003b1235cf248d361126c365a4 . "./code.idejs/ide-inspector.fasl")
(#xa0a1c5e7466b651918d3c8d4b29a6c52 . "./code.idejs/ide-grapher.fasl")
(#x7018e64974e6255373e3b8cc79701650 . "./code.idejs/ide-base.fasl")
(#x454c2906a74451f2bc1a223689c08e37 . "./code.idejs/ide-keyshort.fasl")
(#x2d89e8ba266d3ece361141ce3c8ddde2 . "./code.idejs/ide-dev.fasl")
(#x217a532e6f3391312c3d074df191d31a . "./code.idejs/ide-class-browser.fasl")
(#x49180dfbda8d7e135196d38b2d323132 . "./code.idejs/ide-package-list.fasl")
(#x8ad984ea81da1eb52239eafbdfbde551 . "./code.idejs/ide-intro.fasl")
(#x5d892f2969244933a32098645ae1287b . "./code.idejs/ide-class-grapher.fasl")
(#x8745d7d016911ecfc71df9274030900f . "./code.idejs/ide-window-list.fasl")
(#x49b645043f6a2ac0c39239d758aacd9c . "./code.idejs/ide-find-definitions.fasl")
(#xcdacb28c7dea651f5e792810a681af29 . "./code.idejs/ide-trace.fasl")
(#xcf69ae3489c33d4482cac3d5b07694a3 . "./code.idejs/ide-editor.fasl")
(#x432a822fbbeba0e82af44aeabc7ad8c7 . "./code.idejs/ide-patch-dialog.fasl")
(#x9a4a5ef22fcb7cf09a61cc6582116ccc . "./code.idejs/ide-project.fasl")
(#x87f1221dc5e798b995d2b878a4509d4d . "./code.idejs/ide.fasl")
(#x651742976d39b5f68ccb6ebdf48fa2b0 . "./code.idejs/ide-apropos.fasl")
(#x07c21b2b67ce2e2c8c6c9a8c297a0ce5 . "./code.idejs/ide-acache.fasl")
(#xd82150a8e9f78e0a4a1d968697eeea32 . "./code.idejs/ide-clipboard.fasl")
(#x301c2738f4063ac9d8837361c1d245e2 . "./code.idejs/ide-process-browser.fasl")
(#x0be7cc76458502068af0c4cec4c8cd16 . "./code.idejs/ide-find-in-files.fasl")
(#x720c294c0d8684b20bcff022d815bea5 . "./code.idejs/ide-form.fasl")
(#x8ede4a1e581355e06439292bbf65599b . "./code.idejs/ide-navigator.fasl")
(#x696b64509ebe0538a3b58ac1081d4fa0 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
